==> hobonickels-0.1.tar.gz: hobonickels-0.1/README.md <==
<h1><img src="https://raw.github.com/c0ding/hobonickels-api/master/doc/hobonickels.png" height=55 alt="hobonickels" title="hobonickels"> hobonickels-api</h1>

hobonickels is an APACHE licensed library written in Python designed to provide a simple to use API for the HoboNickels cryptocurrency.

## More about HoboNickels:

HoboNickels is a cryptographic currency, similar to Bitcoin, that is designed to make online transactions easy and efficient.

HoboNickels wallet clients are being actively developed and improved upon. HoboNickels (HBN) is an extremely fast and efficient crypto-currency. With a Proof of Work block time of 30 seconds coupled with fast Proof of Stake, it is pushing to be one of the fastest coins available. The 2-5% Proof of Stake is also one of the most generous staking algorithms released. The stake is designed to keep the inflation rate from getting out of control, with the % of stake decreasing as more people stake the coin. HoboNickels has the added security of a Proof of Stake coin with the addition of security features like Automated Block Checkpoints. HoboNickels are the first coin to use Multi-Wallet functionality.

## Installation:

From source use

    $ python setup.py install

or install from PyPi

    $ pip install hobonickels

## API Documentation:

This API can currently retrieve the following stats from [hbn.blockx.info](http://hbn.blockx.info/) and [CryptoCoin](http://www.cryptocoincharts.info)

Work in progress

## License:

```
  Apache v2.0 License
  Copyright 2014 Martin Simon

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```

## Useful links:

* [Hobonickels website](http://www.hobonickels.info/)
* [Hobonickels Blockexplorer](http://hbn.blockx.info/)

## Buy me a coffee?

If you feel like buying me a coffee (or a beer?), donations are welcome:

```
F2Zs4igv8r4oJJzh4sh4bGmeqoUxLQHPki
```

==> hobonickels-0.2.tar.gz: hobonickels-0.2/README.md <==
<h1><img src="https://raw.github.com/c0ding/hobonickels-api/master/doc/hobonickels.png" height=55 alt="hobonickels" title="hobonickels"> hobonickels-api</h1>

[![PyPi Version](http://img.shields.io/pypi/v/hobonickels.svg)](https://pypi.python.org/pypi/hobonickels/)   [![Downloads](http://img.shields.io/pypi/dm/hobonickels.svg)](https://pypi.python.org/pypi/hobonickels/)

hobonickels is an APACHE licensed library written in Python designed to provide a simple to use API for the HoboNickels cryptocurrency.

## More about HoboNickels:

HoboNickels is a cryptographic currency, similar to Bitcoin, that is designed to make online transactions easy and efficient.

HoboNickels wallet clients are being actively developed and improved upon. HoboNickels (HBN) is an extremely fast and efficient crypto-currency. With a Proof of Work block time of 30 seconds coupled with fast Proof of Stake, it is pushing to be one of the fastest coins available. The 2-5% Proof of Stake is also one of the most generous staking algorithms released. The stake is designed to keep the inflation rate from getting out of control, with the % of stake decreasing as more people stake the coin. HoboNickels has the added security of a Proof of Stake coin with the addition of security features like Automated Block Checkpoints. HoboNickels are the first coin to use Multi-Wallet functionality.

## Installation:

From source use

    $ python setup.py install

or install from PyPi

    $ pip install hobonickels

## API Documentation:

This API can currently retrieve the following stats from [hbn.blockx.info](http://hbn.blockx.info/) and [CryptoCoin](http://www.cryptocoincharts.info)

Work in progress

## License:

```
  Apache v2.0 License
  Copyright 2014 Martin Simon

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```

## Useful links:

* [Hobonickels website](http://www.hobonickels.info/)
* [Hobonickels Blockexplorer](http://hbn.blockx.info/)

## Buy me a coffee?

If you feel like buying me a coffee (or a beer?), donations are welcome:

```
F2Zs4igv8r4oJJzh4sh4bGmeqoUxLQHPki
```
